@@ -1,7 +1,7 @@
 /* Muscle table manager for Bison,
 
-   Copyright (C) 2001-2003, 2006-2015, 2018 Free Software Foundation,
-   Inc.
+   Copyright (C) 2001-2003, 2006-2015, 2018-2019 Free Software
+   Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
 
